TileCacheConfig class

Constructors

TileCacheConfig({double routeBufferKilometers = 5, Duration corridorExpiry = const Duration(days: 30), Duration regionalExpiry = const Duration(days: 90), int corridorMinZoom = 10, int corridorMaxZoom = 16, int metroMinZoom = 9, int metroMaxZoom = 15, int prefectureMinZoom = 7, int prefectureMaxZoom = 13, int nationalMinZoom = 5, int nationalMaxZoom = 10})
const

Properties

corridorExpiry Duration
final
corridorMaxZoom int
final
corridorMinZoom int
final
hashCode int
The hash code for this object.
no setterinherited
metroMaxZoom int
final
metroMinZoom int
final
nationalMaxZoom int
final
nationalMinZoom int
final
prefectureMaxZoom int
final
prefectureMinZoom int
final
regionalExpiry Duration
final
routeBufferKilometers double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

expiryFor(CoverageTier tier) Duration
maxZoomFor(CoverageTier tier) int
minZoomFor(CoverageTier tier) int
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited