RuntimeTileResolution class
Constructors
- RuntimeTileResolution({required RuntimeTileSource source, required TileCoordinates requestedCoordinates, TileCoordinates? resolvedCoordinates, Uint8List? bytes, int scaleFactor = 1, int childX = 0, int childY = 0})
-
const
Properties
- bytes → Uint8List?
-
final
- childX → int
-
final
- childY → int
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasLocalBytes → bool
-
no setter
- requestedCoordinates → TileCoordinates
-
final
- resolvedCoordinates → TileCoordinates?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scaleFactor → int
-
final
- source → RuntimeTileSource
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited